==> carbon-components-react-0.1.8.tgz: package/es/components/SplitButton/SplitButton.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import PropTypes from 'prop-types';
import React, { useState, useRef } from 'react';
import cx from 'classnames';
import { settings } from '@rocketsoftware/carbon-components';
import Button from '../Button';
import OverflowMenu from '../OverflowMenu';
import { ChevronDown16 } from '@rocketsoftware/icons-react';
var prefix = settings.prefix;

var SplitButton = function SplitButton(_ref) {
  var _cx, _cx2, _cx3;

  var classNameContainer = _ref.classNameContainer,
      classNameButton = _ref.classNameButton,
      classNameOverflow = _ref.classNameOverflow,
      disabled = _ref.disabled,
      tabIndex = _ref.tabIndex,
      type = _ref.type,
      role = _ref.role,
      children = _ref.children,
      getViewport = _ref.getViewport,
      other = _objectWithoutProperties(_ref, ["classNameContainer", "classNameButton", "classNameOverflow", "disabled", "tabIndex", "type", "role", "children", "getViewport"]);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      isOpen = _useState2[0],
      setIsOpen = _useState2[1];

  var buttonRef = useRef(null);

  var getOffset = function getOffset() {
    var _buttonRef$current$ge = buttonRef.current.getBoundingClientRect(),
        top = _buttonRef$current$ge.top;

    return {
      top: top * -1,
      left: 'auto'
    };
  };

  var childrenArray = React.Children.toArray(children);
  var primaryAction = childrenArray.splice(0, 1)[0].props;
  var primaryButtonProps = {
    onClick: primaryAction.onClick,
    text: primaryAction.itemText
  };

  var forOnOpen = function forOnOpen() {
    setIsOpen(true);
  };

  var forOnClose = function forOnClose() {
    setIsOpen(false);
  };

  var containerClasses = cx((_cx = {}, _defineProperty(_cx, classNameContainer, true), _defineProperty(_cx, "".concat(prefix, "--btn--split--container"), true), _cx));
  var overflowClasses = cx((_cx2 = {}, _defineProperty(_cx2, classNameOverflow, true), _defineProperty(_cx2, "".concat(prefix, "--btn--split--overflow"), true), _defineProperty(_cx2, "".concat(prefix, "--btn--split--overflow--disabled"), disabled), _cx2));
  var overflowIconClasses = cx((_cx3 = {}, _defineProperty(_cx3, "".concat(prefix, "--btn--split--overflow__open"), isOpen), _defineProperty(_cx3, "".concat(prefix, "--btn--split--overflow--icon"), true), _cx3));
  return React.createElement("div", _extends({
    className: containerClasses,
    tabIndex: tabIndex,
    ref: buttonRef
  }, other, {
    "data-floating-menu-container": true
  }), React.createElement(Button, _extends({
    type: type,
    role: role,
    disabled: disabled,
    className: classNameButton
  }, primaryButtonProps), primaryButtonProps.text), React.createElement(OverflowMenu, {
    className: overflowClasses,
    disabled: disabled,
    onOpen: forOnOpen,
    onClose: forOnClose,
    iconClass: overflowIconClasses,
    menuOptionsClass: "".concat(prefix, "--overflow-menu-options--container"),
    renderIcon: ChevronDown16,
    menuOffset: getOffset,
    getViewport: getViewport
  }, childrenArray.map(function (child) {
    return child;
  })));
};

SplitButton.propTypes = {
  /**
   * Container classes
   */
  classNameContainer: PropTypes.string,

  /**
   * Add an optional class to the button
   */
  classNameButton: PropTypes.string,

  /**
   * Add an optional class to the button
   */
  classNameOverflow: PropTypes.string,

  /**
   * Child nodes to be rendered in secondary actions menu
   */
  children: PropTypes.node.isRequired,

  /**
   * For specifying whether the button is disabled
   */
  disabled: PropTypes.bool,

  /**
   * Optional prop to specify the tabIndex of the SplitButton
   */
  tabIndex: PropTypes.number,

  /**
   * Optional prop to specify the type of the Primary Button
   */
  type: PropTypes.oneOf(['button', 'reset', 'submit']),

  /**
   * Optional prop to specify the role of the Primary Button
   */
  role: PropTypes.string,

  /**
   * Optional callback used to obtain a custom 'viewport' that differs from the window.
   */
  getViewport: PropTypes.func
};
SplitButton.defaultProps = {
  tabIndex: 0,
  type: 'button',
  disabled: false
};
export default SplitButton;

==> carbon-components-react-0.6.1.tgz: package/es/components/SplitButton/SplitButton.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import PropTypes from 'prop-types';
import React, { useState, useRef } from 'react';
import cx from 'classnames';
import { settings } from '@rocketsoftware/carbon-components';
import Button from '../Button';
import OverflowMenu from '../OverflowMenu';
import { ChevronDown16 } from '@rocketsoftware/icons-react';
var prefix = settings.prefix;

var SplitButton = function SplitButton(_ref) {
  var _cx;

  var classNameContainer = _ref.classNameContainer,
      classNameButton = _ref.classNameButton,
      classNameOverflow = _ref.classNameOverflow,
      disabled = _ref.disabled,
      size = _ref.size,
      tabIndex = _ref.tabIndex,
      type = _ref.type,
      role = _ref.role,
      children = _ref.children,
      getViewport = _ref.getViewport,
      other = _objectWithoutProperties(_ref, ["classNameContainer", "classNameButton", "classNameOverflow", "disabled", "size", "tabIndex", "type", "role", "children", "getViewport"]);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      isOpen = _useState2[0],
      setIsOpen = _useState2[1];

  var buttonRef = useRef(null);

  var getOffset = function getOffset() {
    var _buttonRef$current$ge = buttonRef.current.getBoundingClientRect(),
        top = _buttonRef$current$ge.top;

    return {
      top: top * -1,
      left: 'auto'
    };
  };

  var childrenArray = React.Children.toArray(children);
  var primaryAction = childrenArray.splice(0, 1)[0].props;
  var primaryButtonProps = {
    onClick: primaryAction.onClick,
    text: primaryAction.itemText
  };

  var forOnOpen = function forOnOpen() {
    setIsOpen(true);
  };

  var forOnClose = function forOnClose() {
    setIsOpen(false);
  };

  var containerClasses = cx(classNameContainer, "".concat(prefix, "--btn--split--container"));
  var overflowClasses = cx(classNameOverflow, (_cx = {}, _defineProperty(_cx, "".concat(prefix, "--btn--split--overflow--field"), size === 'field'), _defineProperty(_cx, "".concat(prefix, "--btn--split--overflow--sm"), size === 'small'), _defineProperty(_cx, "".concat(prefix, "--btn--split--overflow"), true), _defineProperty(_cx, "".concat(prefix, "--btn--split--overflow--disabled"), disabled), _cx));
  var overflowIconClasses = cx("".concat(prefix, "--btn--split--overflow--icon"), _defineProperty({}, "".concat(prefix, "--btn--split--overflow__open"), isOpen));
  return React.createElement("div", _extends({
    className: containerClasses,
    tabIndex: tabIndex,
    ref: buttonRef
  }, other, {
    "data-floating-menu-container": true
  }), React.createElement(Button, _extends({
    type: type,
    role: role,
    disabled: disabled,
    className: classNameButton,
    size: size
  }, primaryButtonProps), primaryButtonProps.text), React.createElement(OverflowMenu, {
    className: overflowClasses,
    disabled: disabled,
    onOpen: forOnOpen,
    onClose: forOnClose,
    iconClass: overflowIconClasses,
    menuOptionsClass: "".concat(prefix, "--overflow-menu-options--container"),
    renderIcon: ChevronDown16,
    menuOffset: getOffset,
    getViewport: getViewport
  }, childrenArray));
};

SplitButton.propTypes = {
  /**
   * Container classes
   */
  classNameContainer: PropTypes.string,

  /**
   * Add an optional class to the button
   */
  classNameButton: PropTypes.string,

  /**
   * Add an optional class to the button
   */
  classNameOverflow: PropTypes.string,

  /**
   * Child nodes to be rendered in secondary actions menu
   */
  children: PropTypes.node.isRequired,

  /**
   * For specifying whether the button is disabled
   */
  disabled: PropTypes.bool,

  /**
   * For specifying size of split button
   */
  size: PropTypes.oneOf(['default', 'field', 'small']),

  /**
   * Optional prop to specify the tabIndex of the SplitButton
   */
  tabIndex: PropTypes.number,

  /**
   * Optional prop to specify the type of the Primary Button
   */
  type: PropTypes.oneOf(['button', 'reset', 'submit']),

  /**
   * Optional prop to specify the role of the Primary Button
   */
  role: PropTypes.string,

  /**
   * Optional callback used to obtain a custom 'viewport' that differs from the window.
   */
  getViewport: PropTypes.func
};
SplitButton.defaultProps = {
  tabIndex: 0,
  type: 'button',
  disabled: false
};
export default SplitButton;
